@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 29.08.2015: Added importFrom.
 # 07.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
@@ -34,9 +35,11 @@
 #' @param debug logical indicating printing debug information.
 #' @param parent widget to get focus when finished.
 #' 
+#' @return TRUE
+#' 
 #' @export
 #'  
-#' @return TRUE
+#' @importFrom utils help
 #' 
 #' @seealso \code{\link{tableStutter}}
 
@@ -103,7 +106,7 @@ tableStutter_gui <- function(env=parent.frame(), savegui=NULL,
   
   f0g0[1,2] <- f0g0_dataset_drp <- gdroplist(items=c("<Select dataset>",
                                                      listObjects(env=env,
-                                                                 objClass="data.frame")),
+                                                                 obj.class="data.frame")),
                                              selected = 1,
                                              editable = FALSE,
                                              container = f0g0)
